@@ -4,7 +4,7 @@ import pandas as pd
 from astrape.exceptions.exceptions import *
 from astrape.utilities.utils_lightning import *
 from astrape.models.models_lightning import *
-
+from astrape.base.model_base import *
 import pytorch_lightning as pl
 from pytorch_lightning import loggers as pl_loggers
 from sklearn.model_selection import  train_test_split
@@ -215,12 +215,16 @@ class BaseExperiment:
         model_type,
         **hparams : Any
     ):
-        if BaseEstimator in inspect.getmro(model_type):
-            self.model = model_type(**hparams)
-            self.model_metadata = self.set_model_metadata(self.model, hparams)
-        elif pl.LightningModule in inspect.getmro(model_type):
+        
+        if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type): # astrape models
             self.model = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
             self.model_metadata = self.set_model_metadata(self.model, self.model.hparams)
+        elif pl.LightningModule in inspect.getmro(model_type): # other pl.LightningModules not defined in astrape
+            self.model = model_type(**hparams)
+            self.model_metadata = self.set_model_metadata(self.model, self.model.hparams)
+        else: # sklearn-based models
+            self.model = model_type(**hparams)
+            self.model_metadata = self.set_model_metadata(self.model, hparams)
         return self.model
     #######################################################################  set_model (Ends) #######################################################################
 
